@@ -10,12 +10,12 @@ from os.path import expandvars
 from pathlib import Path
 import logging
 from shutil import which
-from typing import List
+from typing import List, Tuple
 
 logger = logging.getLogger(__file__)
 
 
-def _interactive_sub_shell_command(command):
+def _sub_shell_command(command):
     """Build a command to run a given command in an interactive subshell.
 
     Args:
@@ -44,19 +44,34 @@ def _interactive_sub_shell_command(command):
     logger.debug("rc_filepath = %r", rc_filepath)
     interactive = strtobool(expandvars(os.environ.get("VENV_MANAGEMENT_INTERACTIVE_SHELL", "no")))
     logger.debug("interactive = %s", interactive)
+    commands = []
+    use_setup = strtobool(expandvars(os.environ.get("VENV_MANAGEMENT_USE_SETUP", "no")))
     setup_filepath = Path(expandvars(os.environ.get("VENV_MANAGEMENT_SETUP_FILEPATH", str(rc_filepath))))
+    if use_setup:
+        commands.append(f". {setup_filepath}")
+    if command:
+        commands.append(command)
+
     logger.debug("setup_filepath = %s", setup_filepath)
-    if not setup_filepath.is_file():
-        raise RuntimeError(f"Could not find setup file {setup_filepath}")
     args = [
         str(shell_filepath),
         "-c",  # Run command
         *(["-i"] if interactive else []),
-        f". {setup_filepath!s} && {command}",
+        " && ".join(commands),
     ]
     return args
 
 
+def check_environment() -> Tuple[int, str]:
+    """
+
+    Returns: A 2-tuple containing the status output of the setup command, and text output
+
+    """
+    command = _sub_shell_command("")
+    return _getstatusoutput(command)
+
+
 def has_virtualenvwrapper():
     """Determine whether virtualenvwrapper available and working.
 
@@ -87,11 +102,9 @@ def list_virtual_envs() -> List[str]:
     """
     failed_commands = []
     for lsvirtualenv_command in list(lsvirtualenv_commands):
-        command = _interactive_sub_shell_command(lsvirtualenv_command)
+        command = _sub_shell_command(lsvirtualenv_command)
         logger.debug(command)
         status, output = _getstatusoutput(command)
-        logger.debug("status = %d", status)
-        logger.debug("output = %s", output)
         if status == 0:
             break
         failed_commands.append(lsvirtualenv_command)
@@ -133,6 +146,8 @@ def _getstatusoutput(cmd):
                 f"STDOUT: {process.stdout} ; \n"
                 f"STDERR: {process.stderr}"
         )
+    logger.debug("status = %d", status)
+    logger.debug("data = %s", data)
     return status, data
 
 
@@ -209,7 +224,7 @@ def make_virtual_env(
         )
     )
 
-    command = _interactive_sub_shell_command(f"mkvirtualenv {name} {args}")
+    command = _sub_shell_command(f"mkvirtualenv {name} {args}")
     logger.info(command)
     status, output = subprocess.getstatusoutput(command)
     if status != 0:
@@ -297,6 +312,9 @@ def ensure_virtual_env(name, expected_version=None, *, force=False, **kwargs):
     Raises:
         RuntimeError: If the virtual environment couldn't be created or replaced.
     """
+    status, output = check_environment()
+    if status != 0:
+        raise RuntimeError(output)
     python_arg = f"python{expected_version}" if (expected_version is not None) else None
     try:
         env_dirpath = resolve_virtual_env(name)
@@ -339,7 +357,7 @@ def remove_virtual_env(name):
         ValueError: If there is no environment with the given name.
         RuntimeError: If the virtualenv could not be removed.
     """
-    command = _interactive_sub_shell_command(f"rmvirtualenv {name}")
+    command = _sub_shell_command(f"rmvirtualenv {name}")
     logger.info(command)
     status, output = subprocess.getstatusoutput(command)
     if status != 0:
